@@ -1,24 +1,25 @@
 /*
- *  libzvbi - Unicode conversion helper functions
+ *  libzvbi -- Unicode conversion helper functions
  *
  *  Copyright (C) 2003-2006 Michael H. Schimek
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: conv.c,v 1.9 2007/11/27 17:39:36 mschimek Exp $ */
+/* $Id: conv.c,v 1.11 2013-08-28 14:45:43 mschimek Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -785,7 +786,7 @@ strndup_iconv_to_ucs2		(unsigned long *	out_size,
 
 			/* Ignore compiler warnings if second argument
 			   is declared as char** instead of const char**. */
-			r = iconv (cd->icd, &s, &s_left, &d, &d_left);
+			r = iconv (cd->icd, (char **) &s, &s_left, &d, &d_left);
 
 			_vbi_iconv_close (cd);
 			cd = NULL;
