@@ -3,26 +3,23 @@
  *
  *  Copyright (C) 2000, 2001, 2002, 2007 Michael H. Schimek
  *
- *  Based on code from AleVT 1.5.1
- *  Copyright (C) 1998, 1999 Edgar Toernig <froese@gmx.de>
- *  Copyright (C) 1999 Paul Ortyl <ortylp@from.pl>
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: exp-gfx.c,v 1.14 2007/11/27 17:42:15 mschimek Exp $ */
+/* $Id: exp-gfx.c,v 1.19 2013-08-28 14:45:38 mschimek Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
@@ -58,7 +55,7 @@
 
 #define CCPL (ccfont2_width / CCW * ccfont2_height / CCH)
 
-static void init_gfx(void) _vbi_attribute ((constructor));
+static void init_gfx(void) __attribute__ ((constructor));
 
 static void
 init_gfx(void)
@@ -301,12 +298,13 @@ draw_char(int canvas_type, uint8_t *canvas, int rowstride,
 
 		if (!(underline & 1)) {
 #ifdef __GNUC__
+/* FIXME #cpu is deprecated
 #if #cpu (i386)
 			bits = (*((uint16_t *) src) >> shift);
-#else
+#else*/
                         /* unaligned/little endian */
 			bits = ((src[1] * 256 + src[0]) >> shift);
-#endif
+/*#endif*/
 #else
 			bits = ((src[1] * 256 + src[0]) >> shift);
 #endif
@@ -926,7 +924,7 @@ ppm_export			(vbi_export *		e,
 {
 	gfx_instance *gfx = PARENT(e, gfx_instance, export);
 	vbi_rgba *rgba_image;
-	const vbi_rgba *rgba_row_buffer;
+	vbi_rgba *rgba_row_buffer;
 	unsigned int image_width; /* in pixels */
 	unsigned int image_height;
 	unsigned int char_width; /* in pixels */
@@ -1010,7 +1008,7 @@ ppm_export			(vbi_export *		e,
 		if (!vbi_export_flush (e))
 			goto failed;
 
-		rgba_row_buffer = (const vbi_rgba *)
+		rgba_row_buffer = (vbi_rgba *)
 			(e->buffer.data
 			 + ((e->buffer.capacity - rgba_row_size)
 			    & -sizeof (*rgba_row_buffer))); /* align */
@@ -1175,13 +1173,13 @@ draw_drcs_indexed(uint8_t * canvas, int rowstride, uint8_t * pen,
 
 static void
 draw_row_indexed(vbi_page * pg, vbi_char * ac, uint8_t * canvas, uint8_t * pen,
-                 int rowstride, vbi_bool conceal, vbi_bool is_cc, int scale)
+                 int rowstride, vbi_bool conceal, vbi_bool is_cc)
 {
         const int cw = is_cc ? CCW : TCW;
         const int ch = is_cc ? CCH : TCH;
 	void (* draw_char_indexed)(uint8_t *, int, uint8_t *, int, vbi_char *)
                 = is_cc ? draw_char_cc_indexed : draw_char_vt_indexed;
-		int row, column;
+	int column;
         int unicode;
 
         for (column = 0; column < pg->columns ; canvas += cw, column++, ac++) {
@@ -1590,7 +1588,7 @@ xpm_export			(vbi_export *		e,
         for (row = 0; row < (unsigned int) pg->rows; ++row) {
                 draw_row_indexed (pg, &pg->text[row * pg->columns],
 				  indexed_image, pen, image_width,
-				  !e->reveal, pg->columns < 40, scale);
+				  !e->reveal, pg->columns < 40);
 
                 if (!xpm_write_row (e, indexed_image,
 				    image_width, char_height, scale))
@@ -1640,6 +1638,17 @@ VBI_AUTOREG_EXPORT_MODULE(vbi_export_class_xpm)
 #include "png.h"
 #include "setjmp.h"
 
+/* Starting from libpng version 1.5 it is not possible
+   to access inside the PNG struct directly. */
+#ifdef PNG_SETJMP
+#  undef PNG_SETJMP
+#endif
+#if (defined (PNG_LIBPNG_VER) && PNG_LIBPNG_VER >= 10500)
+#  define PNG_SETJMP(ptr) setjmp(png_jmpbuf(ptr))
+#else
+#  define PNG_SETJMP(ptr) setjmp(ptr->jmpbuf)
+#endif
+
 static void
 write_data			(png_structp		png_ptr,
 				 png_bytep		data,
@@ -1675,11 +1684,11 @@ write_png			(gfx_instance *		gfx,
 	char title[80];
 	unsigned int i;
 
-	if (setjmp (png_ptr->jmpbuf))
+	if (PNG_SETJMP(png_ptr))
 		return FALSE;
 
 	png_set_write_fn (png_ptr,
-			  (voidp) gfx,
+			  (png_voidp) gfx,
 			  write_data,
 			  flush_data);
 
@@ -1819,7 +1828,7 @@ png_export(vbi_export *e, vbi_page *pg)
         for (row = 0; row < pg->rows; row++) {
                 draw_row_indexed(pg, &pg->text[row * pg->columns],
                                  image + row * row_adv,  pen, rowstride,
-                                 !e->reveal, pg->columns < 40, scale);
+                                 !e->reveal, pg->columns < 40);
 	}
 
 	/* Now save the image */
