@@ -1,24 +1,25 @@
 /*
- *  libzvbi - Teletext packet page format clear demultiplexer
+ *  libzvbi -- Teletext Page Format Clear packet demultiplexer
  *
- *  Copyright (C) 2003-2004 Michael H. Schimek
+ *  Copyright (C) 2003, 2004, 2007 Michael H. Schimek
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ *  Boston, MA  02110-1301  USA.
  */
 
-/* $Id: pfc_demux.h,v 1.9 2007/11/27 17:41:12 mschimek Exp $ */
+/* $Id: pfc_demux.h,v 1.14 2008-02-24 14:17:10 mschimek Exp $ */
 
 #ifndef __ZVBI_PFC_DEMUX_H__
 #define __ZVBI_PFC_DEMUX_H__
@@ -33,7 +34,7 @@ VBI_BEGIN_DECLS
 /* Public */
 
 /**
- * @addtogroup PFCDemux
+ * @addtogroup PFCDemux Teletext PFC packet demultiplexer
  * @ingroup LowDec
  * @brief Functions to decode data transmissions in Teletext
  *   Page Function Clear packets (EN 300 708 section 4).
@@ -82,7 +83,7 @@ typedef struct _vbi_pfc_demux vbi_pfc_demux;
  * @returns
  * FALSE on error, will be returned by vbi_pfc_demux_feed().
  *
- * @bugs
+ * @bug
  * vbi_pfc_demux_feed() returns the @a user_data pointer as second
  * parameter the @a block pointer as third parameter, but prior to
  * version 0.2.26 this function incorrectly defined @a block as
@@ -95,12 +96,12 @@ vbi_pfc_demux_cb		(vbi_pfc_demux *	dx,
 
 extern void
 vbi_pfc_demux_reset		(vbi_pfc_demux *	dx)
-  _vbi_attribute ((_vbi_nonnull (1)));
+  _vbi_nonnull ((1));
 extern vbi_bool
 vbi_pfc_demux_feed		(vbi_pfc_demux *	dx,
 				 const uint8_t		buffer[42])
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-  _vbi_attribute ((_vbi_nonnull (1, 2)))
+  _vbi_nonnull ((1, 2))
 #endif
   ;
 extern vbi_bool
@@ -108,7 +109,7 @@ vbi_pfc_demux_feed_frame	(vbi_pfc_demux *	dx,
 				 const vbi_sliced *	sliced,
 				 unsigned int		n_lines)
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-  _vbi_attribute ((_vbi_nonnull (1, 2)))
+  _vbi_nonnull ((1, 2))
 #endif
   ;
 extern void
@@ -119,8 +120,7 @@ vbi_pfc_demux_new		(vbi_pgno		pgno,
 				 vbi_pfc_demux_cb *	callback,
 				 void *			user_data)
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
-  _vbi_attribute ((_vbi_alloc,
-		  _vbi_nonnull (3)))
+  _vbi_alloc _vbi_nonnull ((3))
 #endif
   ;
 
@@ -157,21 +157,21 @@ extern void
 _vbi_pfc_block_dump		(const vbi_pfc_block *	pb,
 				 FILE *			fp,
 				 vbi_bool		binary)
-  _vbi_attribute ((_vbi_nonnull (1, 2)));
+  _vbi_nonnull ((1, 2));
 extern vbi_bool
 _vbi_pfc_demux_decode		(vbi_pfc_demux *	dx,
 				 const uint8_t		buffer[42])
-  _vbi_attribute ((_vbi_nonnull (1, 2)));
+  _vbi_nonnull ((1, 2));
 extern void
 _vbi_pfc_demux_destroy		(vbi_pfc_demux *	dx)
-  _vbi_attribute ((_vbi_nonnull (1)));
+  _vbi_nonnull ((1));
 extern vbi_bool
 _vbi_pfc_demux_init		(vbi_pfc_demux *	dx,
 				 vbi_pgno		pgno,
 				 unsigned int		stream,
 				 vbi_pfc_demux_cb *	callback,
 				 void *			user_data)
-  _vbi_attribute ((_vbi_nonnull (1, 4)));
+  _vbi_nonnull ((1, 4));
 
 VBI_END_DECLS
 
