@@ -26,7 +26,7 @@
  *    and dump requested services' data to standard output.  See below
  *    for a list of possible options.
  *
- *  $Log: proxy-test.c,v $
+ *  $Log: not supported by cvs2svn $
  *  Revision 1.20  2008/03/01 07:36:32  mschimek
  *  Line feed cosmetics.
  *
@@ -86,7 +86,7 @@
  */
 
 static const char
-rcsid [] = "$Id: proxy-test.c,v 1.20 2008/03/01 07:36:32 mschimek Exp $";
+rcsid [] = "$Id: proxy-test.c,v 1.21 2008-07-26 06:22:19 mschimek Exp $";
 
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
